@@ -1,5 +1,4 @@
-/* $Id: cmd.h,v 1.4 2001/07/01 11:28:26 mhe Exp $
- *
+/*
  * cmd.h -- read and execute commands, this is the main loop
  *
  * Yet Another FTP Client
@@ -35,6 +34,7 @@ int rearrange_redirections(args_t *args);
 
 void command_loop(void);
 void exit_yafc(void);
+extern void exe_cmdline(char *str, bool aliases_are_expanded);
 
 extern cmd_t cmds[];
 
