@@ -1,5 +1,4 @@
-/* $Id: commands.c,v 1.15 2002/05/09 12:30:49 mhe Exp $
- *
+/*
  * commands.c --
  *
  * Yet Another FTP Client
@@ -58,6 +57,7 @@ cmd_t cmds[] = {
 	CMD(put, 0,0,0, cpLocalFile),
 	CMD(pwd, 0,0,1, cpNone),
 	CMD(quit, 0,0,1, cpNone),
+	CMD(exit, 0,0,1, cpNone),
 	CMD(quote, 0,0,1, cpNone),
 	CMD(mv, 0,0,1, cpRemoteFile),
 	CMD(reopen, 1,1,1, cpNone),
@@ -79,10 +79,10 @@ cmd_t cmds[] = {
 	CMD(user, 0,0,1, cpNone),
 	CMD(version, 0,0,1, cpNone),
 	CMD(warranty, 0,0,1, cpNone),
-#if defined(KRB4) || defined(KRB5)
+#ifdef HAVE_KERBEROS
 	CMD(prot, 1,1,1, cpNone),
 #endif
-#ifdef KRB4
+#ifdef HAVE_KRB4
 	CMD(afslog, 0,0,1, cpNone),
 	CMD(klist, 0,0,1, cpNone),
 	CMD(kauth, 0,0,1, cpNone),
@@ -143,7 +143,7 @@ int rearrange_args(args_t *args, const char *rchars)
 			num = (size_t)(e - args->argv[i]);
 			a = xstrndup(args->argv[i], num);
 			args_insert_string(args, i, a);
-			xfree(a);
+			free(a);
 			strpull(args->argv[i+1], num);
 			break;
 		}
@@ -221,14 +221,14 @@ void expand_alias_parameters(args_t **args, args_t *alias_args)
 
 			if(ep != e && n < alias_args->argc && n >= 0) {
 				ins = deleted->argv[n];
-				xfree(alias_args->argv[n]);
+				free(alias_args->argv[n]);
 				alias_args->argv[n] = 0;
 			} else
 				ins = 0;
 
 			/* insert the parameter in this argument */
 			asprintf(&tmp, "%s%s%s", new_args->argv[i], ins ? ins : "", ep);
-			xfree(new_args->argv[i]);
+			free(new_args->argv[i]);
 			new_args->argv[i] = tmp;
 		}
 
@@ -345,7 +345,7 @@ void cmd_list(int argc, char **argv)
 
 		args = args_cat(argc, argv, optind);
 		ftp_list("LIST", args, stdout);
-		xfree(args);
+		free(args);
 	}
 }
 
@@ -365,7 +365,7 @@ void cmd_nlist(int argc, char **argv)
 
 		args = args_cat(argc, argv, optind);
 		ftp_list("NLST", args, stdout);
-		xfree(args);
+		free(args);
 	}
 }
 
@@ -459,7 +459,7 @@ void cmd_cd(int argc, char **argv)
 		e = argv[1];
 	e = tilde_expand_home(e, ftp->homedir);
 	ftp_chdir(e);
-	xfree(e);
+	free(e);
 }
 
 void cmd_cdup(int argc, char **argv)
@@ -486,7 +486,7 @@ void opt_help(int argc, char **argv, char *help)
 	while((c = getopt_long(argc, argv, "h", longopts, 0)) != EOF) {
 		switch(c) {
 		  case 'h':
-			fprintf(stderr, help);
+			fprintf(stderr, "%s", help);
 		  case '?':
 			optind = -1;
 			return;
@@ -554,7 +554,7 @@ void cmd_url(int argc, char **argv)
 	if(!url_isanon(ftp->url)) {
 		char *e = encode_url_username(ftp->url->username);
 		printf("%s@", e);
-		xfree(e);
+		free(e);
 	}
 	printf("%s", ftp->url->hostname);
 	if(ftp->url->port != 21)
@@ -568,7 +568,7 @@ void cmd_url(int argc, char **argv)
 #endif
 		d = encode_url_directory(e);
 		printf("/%s", d);
-		xfree(d);
+		free(d);
 	}
 	printf("\n");
 }
@@ -597,7 +597,7 @@ void cmd_rhelp(int argc, char **argv)
 
 	e = args_cat(argc, argv, 1);
 	ftp_help(e);
-	xfree(e);
+	free(e);
 }
 
 void cmd_mkdir(int argc, char **argv)
@@ -693,7 +693,7 @@ void cmd_status(int argc, char **argv)
 		puts(_("not connected"));
 	if(ftp_loggedin())
 		printf(_("logged in as '%s'\n"), ftp->url->username);
-#if defined(KRB4) || defined(KRB5)
+#ifdef HAVE_KERBEROS
 	if(ftp_connected())
 		sec_status();
 #endif
@@ -706,15 +706,6 @@ void cmd_site(int argc, char **argv)
 {
 	char *e;
 
-#if 0
-	OPT_HELP("Send site specific command.  Usage:\n"
-			 "  site [options] [command]\n"
-			 "Options:\n"
-			 "  -h, --help    show this help\n"
-			 "[command] should be a valid SITE argument\n"
-			 "try 'site help' or 'rhelp site' for more information\n");
-#endif
-
 	minargs_nohelp(1);
 	need_connected();
 
@@ -726,7 +717,7 @@ void cmd_site(int argc, char **argv)
 	e = args_cat(argc, argv, 1);
 	ftp_set_tmp_verbosity(vbCommand);
 	ftp_cmd("SITE %s", e);
-	xfree(e);
+	free(e);
 }
 
 void cmd_chmod(int argc, char **argv)
@@ -851,7 +842,7 @@ void cmd_quote(int argc, char **argv)
 	e = args_cat(argc, argv, optind);
 	ftp_set_tmp_verbosity(vbDebug);
 	ftp_cmd("%s", e);
-	xfree(e);
+	free(e);
 }
 
 void cmd_filetime(int argc, char **argv)
